@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import functools
 import logging
 import re
 from datetime import datetime
@@ -23,7 +22,7 @@ from functools import partial
 from io import TextIOWrapper
 from operator import getitem, itemgetter
 from pathlib import Path
-from time import time as time_now
+from time import perf_counter
 
 import click
 import click_log
@@ -38,7 +37,7 @@ from simplejson import dumps as json_dumps
 from . import CLI_NAME, __version__, env_data, logger, reset_logger
 from .base import CLI_FORMATS, PackageManager
 from .config import load_conf
-from .managers import pool, select_managers
+from .managers import ALL_MANAGER_IDS, select_managers
 from .platform import os_label
 from .version import TokenizedString
 
@@ -151,26 +150,12 @@ def print_stats(data):
     click.echo(f"{total_installed} package{plural} total{per_manager_totals}.")
 
 
-class timeit:
-    """Decorator to measure and print elapsed execution time of a function."""
-
-    def __call__(self, func):
-        @functools.wraps(func)
-        def decorated(*args, **kwargs):
-            with self:
-                return func(*args, **kwargs)
-
-        return decorated
-
-    def __enter__(self):
-        self.measure_time = click.get_current_context().obj["time"]
-        if self.measure_time:
-            self.start_time = time_now()
-
-    def __exit__(self, *args, **kwargs):
-        if self.measure_time:
-            elapsed = time_now() - self.start_time
-            click.echo(f"Execution time: {elapsed:.3} seconds.")
+def timeit():
+    """Print elapsed execution time."""
+    ctx = click.get_current_context()
+    if ctx.obj["time"]:
+        start_time = ctx.obj["start_time"]
+        click.echo(f"Execution time: {perf_counter() - start_time:0.3f} seconds.")
 
 
 @click.group(
@@ -182,7 +167,7 @@ class timeit:
 @click.option(
     "-m",
     "--manager",
-    type=click.Choice(pool(), case_sensitive=False),
+    type=click.Choice(sorted(ALL_MANAGER_IDS), case_sensitive=False),
     multiple=True,
     help="Restrict sub-command to a subset of package managers. Repeat to "
     "select multiple managers.",
@@ -190,10 +175,19 @@ class timeit:
 @click.option(
     "-e",
     "--exclude",
-    type=click.Choice(pool(), case_sensitive=False),
+    type=click.Choice(sorted(ALL_MANAGER_IDS), case_sensitive=False),
     multiple=True,
     help="Exclude a package manager. Repeat to exclude multiple managers.",
 )
+@click.option(
+    "-a",
+    "--all-managers",
+    is_flag=True,
+    default=False,
+    help="Force evaluation of all package manager implemented by mpm, even those not"
+    "supported by the current platform. Still applies filtering by --manager and "
+    "--exclude options before calling the subcommand.",
+)
 @click.option(
     "--ignore-auto-updates/--include-auto-updates",
     default=True,
@@ -210,7 +204,7 @@ class timeit:
 @click.option(
     "-s",
     "--sort-by",
-    type=click.Choice(SORTABLE_FIELDS, case_sensitive=False),
+    type=click.Choice(sorted(SORTABLE_FIELDS), case_sensitive=False),
     default="manager_id",
     help="Sort results.",
 )
@@ -269,6 +263,7 @@ def cli(
     ctx,
     manager,
     exclude,
+    all_managers,
     ignore_auto_updates,
     output_format,
     sort_by,
@@ -278,6 +273,8 @@ def cli(
     dry_run,
 ):
     """CLI for multi-package manager upgrades."""
+    # Take timestamp snapshot.
+    start_time = perf_counter() if time else None
 
     # Print log level.
     level = logger.level
@@ -285,9 +282,13 @@ def cli(
     logger.debug(f"Verbosity set to {level_name}.")
 
     # Select the subset of manager to target, and apply manager-level options.
-    target_managers = select_managers(
+    selected_managers = select_managers(
         keep=manager,
         drop=exclude,
+        drop_unsupported=not all_managers,
+        # Only keep inactive managers to show them in the "managers" subcommand table.
+        # Filters them out in any other subcommand.
+        drop_inactive=ctx.invoked_subcommand != "managers",
         # Does the manager should raise on error or not.
         stop_on_error=stop_on_error,
         # Should we include auto-update packages or not?
@@ -295,16 +296,6 @@ def cli(
         dry_run=dry_run,
     )
 
-    # Pre-filters inactive managers.
-    def keep_available(manager):
-        if manager.available:
-            return True
-        logger.warning(f"Skip unavailable {manager.id} manager.")
-
-    # Use an iterator to not trigger log messages for the 'managers' subcommand
-    # which is not using this variable.
-    active_managers = filter(keep_available, target_managers)
-
     # Silence all log message for JSON rendering unless in debug mode.
     if output_format == "json" and level_name != "DEBUG":
         logger.setLevel(logging.CRITICAL * 2)
@@ -315,23 +306,23 @@ def cli(
 
     # Load up global options to the context.
     ctx.obj = {
-        "target_managers": target_managers,
-        "active_managers": active_managers,
+        "selected_managers": selected_managers,
         "output_format": output_format,
         "sort_by": sort_by,
         "stats": stats,
         "time": time,
+        "start_time": start_time,
     }
 
     ctx.call_on_close(reset_logger)
+    ctx.call_on_close(timeit)
 
 
 @cli.command(short_help="List supported package managers and their location.")
 @click.pass_context
-@timeit()
 def managers(ctx):
     """List all supported package managers and their presence on the system."""
-    target_managers = ctx.obj["target_managers"]
+    selected_managers = ctx.obj["selected_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
 
@@ -349,7 +340,7 @@ def managers(ctx):
             "fresh",
             "available",
         ]
-        for manager in target_managers:
+        for manager in selected_managers:
             manager_data[manager.id] = {fid: getattr(manager, fid) for fid in fields}
             # Serialize errors at the last minute to gather all we encountered.
             manager_data[manager.id]["errors"] = list(
@@ -361,7 +352,7 @@ def managers(ctx):
 
     # Human-friendly content rendering.
     table = []
-    for manager in target_managers:
+    for manager in selected_managers:
 
         # Build up the OS column content.
         os_infos = OK if manager.supported else KO
@@ -375,7 +366,7 @@ def managers(ctx):
             OK if manager.cli_path else KO,
             manager.cli_path
             if manager.cli_path
-            else f"no {', '.join(manager.cli_names)} found",
+            else f"{', '.join(manager.cli_names)} not found",
         )
 
         # Build up the version column content.
@@ -414,32 +405,29 @@ def managers(ctx):
 
 @cli.command(short_help="Sync local package info.")
 @click.pass_context
-@timeit()
 def sync(ctx):
     """Sync local package metadata and info from external sources."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
 
-    for manager in active_managers:
+    for manager in selected_managers:
         manager.sync()
 
 
 @cli.command(short_help="Cleanup local data.")
 @click.pass_context
-@timeit()
 def cleanup(ctx):
     """Cleanup local data and temporary artifacts."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
 
-    for manager in active_managers:
+    for manager in selected_managers:
         manager.cleanup()
 
 
 @cli.command(short_help="List installed packages.")
 @click.pass_context
-@timeit()
 def installed(ctx):
     """List all packages installed on the system from all managers."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
     stats = ctx.obj["stats"]
@@ -447,7 +435,7 @@ def installed(ctx):
     # Build-up a global dict of installed packages per manager.
     installed_data = {}
 
-    for manager in active_managers:
+    for manager in selected_managers:
         installed_data[manager.id] = {
             "id": manager.id,
             "name": manager.name,
@@ -507,10 +495,9 @@ def installed(ctx):
 )
 @click.argument("query", type=click.STRING, required=True)
 @click.pass_context
-@timeit()
 def search(ctx, extended, exact, query):
     """Search packages from all managers."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
     stats = ctx.obj["stats"]
@@ -518,7 +505,7 @@ def search(ctx, extended, exact, query):
     # Build-up a global list of package matches per manager.
     matches = {}
 
-    for manager in active_managers:
+    for manager in selected_managers:
 
         # Allow managers to not implement search.
         try:
@@ -551,17 +538,15 @@ def search(ctx, extended, exact, query):
         # Ranges of character indices flagged for highlighting.
         ranges = set()
 
-        # TODO: Fix upper-case matching, as tokenizer lower them down.
-
         for part in query_parts:
             # Search for occurrences of query parts in original string.
-            if part in string:
-                # Flag matching substrings for highlighting.
-                occurrences = [match.start() for match in re.finditer(part, string)]
-
-                for match_start in occurrences:
-                    match_end = match_start + len(part) - 1
-                    ranges.add(f"{match_start}-{match_end}")
+            occurrences = [
+                match.start() for match in re.finditer(part, string, re.IGNORECASE)
+            ]
+            # Flag matching substrings for highlighting.
+            for match_start in occurrences:
+                match_end = match_start + len(part) - 1
+                ranges.add(f"{match_start}-{match_end}")
 
         # Reduce index ranges, compute complement ranges, transform them to
         # list of integers.
@@ -613,22 +598,21 @@ def search(ctx, extended, exact, query):
 @cli.command(short_help="Install a package.")
 @click.argument("package_id", type=click.STRING, required=True)
 @click.pass_context
-@timeit()
 def install(ctx, package_id):
     """Install a package from one package manager and one only.
 
     The -m\--manager option is required."""
-    active_managers = ctx.obj["active_managers"]
-    active_managers = list(active_managers)
+    selected_managers = ctx.obj["selected_managers"]
+    selected_managers = list(selected_managers)
 
-    if not active_managers:
+    if not selected_managers:
         logger.fatal(f"A package manager must be provided via the -m/--manager option.")
         ctx.exit(2)
-    if len(active_managers) > 1:
+    if len(selected_managers) > 1:
         logger.fatal(f"Only one package manager should be provided.")
         ctx.exit(2)
 
-    manager = active_managers.pop()
+    manager = selected_managers.pop()
     output = manager.install(package_id)
     click.echo(output)
 
@@ -637,15 +621,14 @@ def install(ctx, package_id):
 @click.option(
     "-c",
     "--cli-format",
-    type=click.Choice(CLI_FORMATS, case_sensitive=False),
+    type=click.Choice(sorted(CLI_FORMATS), case_sensitive=False),
     default="plain",
     help="Format of CLI fields in JSON output.",
 )
 @click.pass_context
-@timeit()
 def outdated(ctx, cli_format):
     """List available package upgrades and their versions for each manager."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
     stats = ctx.obj["stats"]
@@ -655,7 +638,7 @@ def outdated(ctx, cli_format):
     # Build-up a global list of outdated packages per manager.
     outdated_data = {}
 
-    for manager in active_managers:
+    for manager in selected_managers:
 
         try:
             packages = list(map(dict, manager.outdated.values()))
@@ -674,7 +657,7 @@ def outdated(ctx, cli_format):
 
         # Do not include the full-upgrade CLI if we did not detect any outdated
         # package.
-        if manager.outdated:
+        if packages:
             try:
                 upgrade_all_cli = manager.upgrade_all_cli()
             except NotImplementedError:
@@ -726,12 +709,11 @@ def outdated(ctx, cli_format):
 
 @cli.command(short_help="Upgrade all packages.")
 @click.pass_context
-@timeit()
 def upgrade(ctx):
     """Perform a full package upgrade on all available managers."""
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
 
-    for manager in active_managers:
+    for manager in selected_managers:
         logger.info(f"Updating all outdated packages from {manager.id}...")
         try:
             output = manager.upgrade_all()
@@ -746,7 +728,6 @@ def upgrade(ctx):
 @cli.command(short_help="Save installed packages to a TOML file.")
 @click.argument("toml_output", type=click.File("w"), default="-")
 @click.pass_context
-@timeit()
 def backup(ctx, toml_output):
     """Dump the list of installed packages to a TOML file.
 
@@ -757,7 +738,7 @@ def backup(ctx, toml_output):
 
     The TOML file can then be safely consumed by the `mpm restore` command.
     """
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
     stats = ctx.obj["stats"]
 
     is_stdout = isinstance(toml_output, TextIOWrapper)
@@ -779,7 +760,7 @@ def backup(ctx, toml_output):
     installed_data = {}
 
     # Create one section for each package manager.
-    for manager in active_managers:
+    for manager in selected_managers:
         logger.info(f"Dumping packages from {manager.id}...")
         installed_packages = manager.installed.values()
 
@@ -805,14 +786,13 @@ def backup(ctx, toml_output):
 @cli.command(short_help="Install packages in batch as specified by TOML files.")
 @click.argument("toml_files", type=click.File("r"), required=True, nargs=-1)
 @click.pass_context
-@timeit()
 def restore(ctx, toml_files):
     """Read TOML files then install or upgrade each package referenced in
     them.
 
     Version specified in the TOML file is ignored in the current implementation.
     """
-    active_managers = ctx.obj["active_managers"]
+    selected_managers = ctx.obj["selected_managers"]
 
     for toml_input in toml_files:
 
@@ -823,13 +803,15 @@ def restore(ctx, toml_files):
         doc = tomli.loads(toml_input.read())
 
         # List unrecognized sections.
-        ignored_sections = [f"[{section}]" for section in doc if section not in pool()]
+        ignored_sections = [
+            f"[{section}]" for section in doc if section not in ALL_MANAGER_IDS
+        ]
         if ignored_sections:
             plural = "s" if len(ignored_sections) > 1 else ""
             sections = ", ".join(ignored_sections)
             logger.info(f"Ignore {sections} section{plural}.")
 
-        for manager in active_managers:
+        for manager in selected_managers:
             if manager.id not in doc:
                 logger.warning(f"No [{manager.id}] section found.")
                 continue
