@@ -18,8 +18,8 @@
 """ Registration, indexing and cache of package manager definitions. """
 
 import inspect
-from collections import OrderedDict
 from importlib import import_module
+from operator import getitem, itemgetter
 from pathlib import Path
 
 from boltons.cacheutils import LRI, cached
@@ -38,8 +38,6 @@ def pool():
         1 - are sub-classes of PackageManager, and
         2 - are located in files at the same level or below this one, and
         3 - are not virtual (i.e. have a non null `cli_names` property).
-
-    Returns an `OrderedDict` sorted by manager's ID.
     """
     register = {}
 
@@ -55,43 +53,63 @@ def pool():
             else:
                 logger.debug(f"{klass!r} is not a valid manager definition")
 
-    # Sort pool entries by ID.
-    # TODO: propose an OrderedFrozenDict in boltons and use it here.
-    return OrderedDict(sorted(register.items()))
+    return register
 
 
-def select_managers(keep=None, drop=None, **kwargs):
-    """ "Utility method to extract a subset of the manager pool based on selection and exclusion criterion.
+# Pre-compute all sorts of constants.
+
+ALL_MANAGER_IDS = frozenset(pool())
+""" All recognized manager IDs. """
+
+DEFAULT_MANAGER_IDS = frozenset({m.id for m in pool().values() if m.supported})
+""" All manager IDs supported on the current platform. """
+
+UNSUPPORTED_MANAGER_IDS = frozenset(ALL_MANAGER_IDS - DEFAULT_MANAGER_IDS)
+""" All manager IDs unsupported on the current platform. """
+
+
+def select_managers(
+    keep=None, drop=None, drop_unsupported=True, drop_inactive=True, **kwargs
+):
+    """Utility method to extract a subset of the manager pool based on selection and
+    exclusion criterion.
 
     By default, all managers are selected.
 
     kwargs are fed to the manager objects from the pool to set some options.
 
-    Returns a list of manager objects sorted by IDs.
+    Returns a generator returning manager objects one by one.
     """
-    selected_ids = set(pool())
+    selected_ids = DEFAULT_MANAGER_IDS if drop_unsupported else ALL_MANAGER_IDS
 
     if not keep:
         keep = selected_ids
     if not drop:
         drop = set()
-    assert isinstance(keep, (set, tuple, list))
-    assert isinstance(drop, (set, tuple, list))
+    assert isinstance(keep, (set, frozenset, tuple, list))
+    assert isinstance(drop, (set, frozenset, tuple, list))
 
     # Only keeps the subset selected by the user.
     selected_ids = selected_ids.intersection(keep)
     # Remove managers excluded by the user.
     selected_ids = selected_ids.difference(drop)
 
-    selected_managers = [pool()[mid] for mid in sorted(selected_ids)]
-
-    # List of supported manager options.
+    # List of recognized manager options.
     option_ids = {"stop_on_error", "ignore_auto_updates", "dry_run"}
     assert option_ids.issuperset(kwargs)
-    # Apply manager-level options.
-    for m_obj in selected_managers:
-        for param, value in kwargs.items():
-            assert hasattr(m_obj, param)
-            setattr(m_obj, param, value)
 
-    return selected_managers
+    for manager in [pool()[mid] for mid in selected_ids]:
+
+        # TODO: check if not implemeted before calling .available. It saves one call to the package manager CLI.
+
+        # Filters out inactive managers.
+        if drop_inactive and not manager.available:
+            logger.warning(f"Skip unavailable {manager.id} manager.")
+            continue
+
+        # Apply manager-level options.
+        for param, value in kwargs.items():
+            assert hasattr(manager, param)
+            setattr(manager, param, value)
+
+        yield manager
