@@ -35,7 +35,8 @@ class APT(PackageManager):
     requirement = "1.0.0"
 
     version_regex = r"apt\s+(?P<version>\S+)"
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► apt --version
         apt 1.2.15 (amd64)
@@ -43,9 +44,6 @@ class APT(PackageManager):
 
     def sync(self):
         """
-
-        Raw CLI output samples:
-
         .. code-block:: shell-session
 
             ► apt update --quiet
@@ -252,9 +250,6 @@ class APT(PackageManager):
             cmd.append(package_id)
         return cmd
 
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
-
     def cleanup(self):
         """Runs:
 
@@ -280,7 +275,8 @@ class APT_Mint(APT):
     cli_names = ["apt"]
 
     version_cli_options = ["version", "apt"]
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► apt version apt
         1.6.11
