@@ -30,7 +30,8 @@ class Flatpak(PackageManager):
     requirement = "1.2.0"
 
     version_regex = r"Flatpak\s+(?P<version>\S+)"
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► flatpak --version
         Flatpak 1.4.2
@@ -207,9 +208,6 @@ class Flatpak(PackageManager):
             cmd.append(package_id)
         return cmd
 
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
-
     def cleanup(self):
         """Runs:
 
