@@ -34,7 +34,8 @@ class MAS(PackageManager):
     name = "Mac AppStore"
 
     version_cli_options = ["version"]
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► mas version
         1.8.3
@@ -182,6 +183,3 @@ class MAS(PackageManager):
         if package_id:
             cmd.append(package_id)
         return cmd
-
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
