@@ -31,7 +31,8 @@ class NPM(PackageManager):
 
     name = "Node's npm"
 
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► npm --version
         6.13.7
@@ -308,6 +309,3 @@ class NPM(PackageManager):
         else:
             cmd_args.append("update")
         return [self.cli_path, self.global_args] + cmd_args
-
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
