@@ -29,7 +29,8 @@ class OPKG(PackageManager):
     requirement = "0.2.0"
 
     version_regex = r"opkg\s+version\s+(?P<version>\S+)"
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► opkg --version
         opkg version 0.3.6 (libsolv 0.7.5)
@@ -191,6 +192,3 @@ class OPKG(PackageManager):
         if package_id:
             cmd.append(package_id)
         return cmd
-
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
