@@ -29,7 +29,8 @@ class Snap(PackageManager):
     global_args = ["--color=never"]
 
     version_regex = r"snap\s+(?P<version>\S+)"
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► snap --version
         snap       2.44.1
@@ -156,14 +157,11 @@ class Snap(PackageManager):
 
         return outdated
 
-    def upgrade_cli(self, package_id):
-        """snap has an auto-update function, but snaps can be updated
-        manually.
-        """
-        return [self.cli_path, self.global_args, "refresh", package_id]
-
-    def upgrade_all_cli(self):
+    def upgrade_cli(self, package_id=None):
         """Snap has an auto-update function, but snaps can be updated
         manually.
         """
-        return [self.cli_path, self.global_args, "refresh"]
+        cmd = [self.cli_path, self.global_args, "refresh"]
+        if package_id:
+            cmd.append(package_id)
+        return cmd
