@@ -34,7 +34,8 @@ class Yarn(PackageManager):
 
     requirement = "1.21.0"
 
-    """.. code-block:: shell-session
+    """
+    .. code-block:: shell-session
 
         ► yarn --version
         1.22.11
@@ -257,9 +258,6 @@ class Yarn(PackageManager):
 
         return cmd
 
-    def upgrade_all_cli(self):
-        return self.upgrade_cli()
-
     def cleanup(self):
         """Remove the shared cache files.
 
