@@ -21,7 +21,7 @@ import pytest
 import simplejson as json
 from boltons.iterutils import same
 
-from .conftest import MANAGER_IDS
+from ..managers import ALL_MANAGER_IDS, DEFAULT_MANAGER_IDS, UNSUPPORTED_MANAGER_IDS
 from .test_cli import CLISubCommandTests, CLITableTests
 
 
@@ -31,12 +31,24 @@ def subcmd():
 
 
 class TestManagers(CLISubCommandTests, CLITableTests):
-    @pytest.mark.parametrize("mid", MANAGER_IDS)
-    def test_single_manager(self, invoke, subcmd, mid):
+    @pytest.mark.parametrize("mid", DEFAULT_MANAGER_IDS)
+    def test_default_managers(self, invoke, subcmd, mid):
         result = invoke("--manager", mid, subcmd)
         assert result.exit_code == 0
         self.check_manager_selection(result, {mid})
 
+    @pytest.mark.parametrize("mid", ALL_MANAGER_IDS)
+    def test_all_managers(self, invoke, subcmd, mid):
+        result = invoke("--manager", mid, "--all-managers", subcmd)
+        assert result.exit_code == 0
+        self.check_manager_selection(result, {mid}, ALL_MANAGER_IDS)
+
+    @pytest.mark.parametrize("mid", UNSUPPORTED_MANAGER_IDS)
+    def test_unsupported_managers(self, invoke, subcmd, mid):
+        result = invoke("--manager", mid, subcmd)
+        assert result.exit_code == 0
+        self.check_manager_selection(result, set())
+
     def test_json_parsing(self, invoke, subcmd):
         result = invoke("--output-format", "json", subcmd)
         assert result.exit_code == 0
@@ -44,7 +56,7 @@ class TestManagers(CLISubCommandTests, CLITableTests):
 
         assert data
         assert isinstance(data, dict)
-        assert set(data) == MANAGER_IDS
+        assert set(data) == DEFAULT_MANAGER_IDS
 
         for manager_id, info in data.items():
             assert isinstance(manager_id, str)
