@@ -17,7 +17,7 @@
 
 import pytest
 
-from .conftest import MANAGER_IDS
+from ..managers import ALL_MANAGER_IDS, DEFAULT_MANAGER_IDS
 from .test_cli import CLISubCommandTests
 
 
@@ -47,7 +47,7 @@ class TestRestore(CLISubCommandTests):
             """.format(
                         m
                     )
-                    for m in MANAGER_IDS
+                    for m in ALL_MANAGER_IDS
                 ]
             ),
         )
@@ -57,7 +57,7 @@ class TestRestore(CLISubCommandTests):
         assert "all-managers.toml" in result.stderr
         self.check_manager_selection(result)
 
-    @pytest.mark.parametrize("mid", MANAGER_IDS)
+    @pytest.mark.parametrize("mid", DEFAULT_MANAGER_IDS)
     def test_single_manager(self, invoke, create_toml, mid):
         toml_path = create_toml(
             "all-managers.toml",
@@ -69,7 +69,7 @@ class TestRestore(CLISubCommandTests):
             """.format(
                         m
                     )
-                    for m in MANAGER_IDS
+                    for m in ALL_MANAGER_IDS
                 ]
             ),
         )
