@@ -21,13 +21,14 @@ from pathlib import Path
 
 import pytest
 import simplejson as json
+import tomli
 from boltons.iterutils import flatten
 from yaml import Loader, load
 
 from ..labels import MANAGER_LABELS, MANAGER_PREFIX, PLATFORM_LABELS, PLATFORM_PREFIX
-from ..managers import pool
+from ..managers import ALL_MANAGER_IDS, pool
 from ..platform import OS_DEFINITIONS, os_label
-from .conftest import MANAGER_IDS, unless_linux
+from .conftest import unless_linux
 
 """ Test all non-code artifacts depending on manager definitions.
 
@@ -43,6 +44,14 @@ platform or manager addition.
 PROJECT_ROOT = Path(__file__).parent.parent.parent
 
 
+def test_project_metadata():
+    # Fetch general information about the project from pyproject.toml.
+    toml_path = Path(__file__).parent.joinpath("../../pyproject.toml").resolve()
+    toml_config = tomli.loads(toml_path.read_text())
+    # Check all managers are referenced in Python package keywords.
+    assert ALL_MANAGER_IDS.issubset(toml_config["tool"]["poetry"]["keywords"])
+
+
 def test_changelog():
     content = PROJECT_ROOT.joinpath("changelog.rst").read_text()
 
@@ -56,7 +65,9 @@ def test_changelog():
             entry = match.groupdict()
             assert entry["category"]
             assert set(entry["category"].split(",")).issubset(
-                flatten([MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar", "xbar"])
+                flatten(
+                    [ALL_MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar", "xbar"]
+                )
             )
 
 
