@@ -16,40 +16,27 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import re
-from operator import attrgetter, itemgetter
+from operator import attrgetter
 from pathlib import Path, PurePath
 from string import ascii_letters, ascii_lowercase, digits
 from types import MethodType
 
 import pytest
 
-from ..managers import pool
+from ..managers import ALL_MANAGER_IDS, pool
 from ..platform import OS_DEFINITIONS
 from ..version import TokenizedString
-from .conftest import MANAGER_IDS
 
-""" Test the structure, data and types returned by all package managers. """
+""" Test the structure, data and types returned by all package managers.
+
+This test suite try to automate most of the basic reviewing work for the addition of
+new package manager definitions.
+"""
 
 # Parametrization decorators.
 all_managers = pytest.mark.parametrize("manager", pool().values(), ids=attrgetter("id"))
 
 
-def test_manager_count():
-    """Check all implemented package managers are accounted for."""
-    assert len(pool()) == 15
-    assert len(pool()) == len(MANAGER_IDS)
-    assert MANAGER_IDS == set(pool())
-
-
-def test_cached_pool():
-    assert pool() == pool()
-    assert pool() is pool()
-
-
-def test_sorted_pool():
-    assert list(pool()) == sorted([m.id for m in pool().values()])
-
-
 @pytest.mark.parametrize("manager_id,manager", pool().items())
 def test_ascii_id(manager_id, manager):
     """All package manager IDs should be short ASCII strings."""
@@ -69,7 +56,7 @@ def test_name(manager):
 
 
 def test_unique_names():
-    assert len({m.name for m in pool().values()}) == len(MANAGER_IDS)
+    assert len({m.name for m in pool().values()}) == len(ALL_MANAGER_IDS)
 
 
 @all_managers
